/*
 * iwconnect/iwconnect.h
 * $Rev: 1222 $
 *
 * Copyright (C) 2008-2010, Reto Gantenbein <reto.gantenbein@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * @file iwconnect.h
 * @brief iwconnect types and general functions
 */

#ifndef __IWCONNECT_H
#define __IWCONNECT_H

/* INCLUDES *******************************************************************/

#include <netinet/in.h>
#include <linux/if.h>               // IFNAMSIZ
#include <linux/if_ether.h>         // ETH_ALEN
#include <limits.h>                 // HOST_NAME_MAX
#include <netdb.h>                  // struct addrinfo, struct sockaddr
#include <vif.h>                    // MAX_NUM_VIF


/* PM TYPES *******************************************************************/

/** Host/connection information */
typedef struct iwc_host_info {
    char                    hostname[HOST_NAME_MAX + 1];   /**< Host name */
    struct addrinfo         addr_info;  /**< Generic address information (IPv4/v6) */
    struct sockaddr_storage addr;       /**< IP/port (v4: sockaddr_in, v6: sockaddr_in6) */
}
iwc_host_info;

/** Wireless client info */
typedef struct iwc_client_info {
    char            host_id[2 * ETH_ALEN + 1];  /**< Host identifier */
    iwc_host_info    host_info;                  /**< Client host information */
    char            host_if[IFNAMSIZ + 1];      /**< Physical network device name */
    unsigned char   host_mac[ETH_ALEN];         /**< physical network device MAC address */
    char            host_port[5];            //TODO: remove -> DEPRICATED!
}
iwc_client_info;

/** Wireless model info */
typedef struct iwc_model_info {
    iwc_host_info    host_info;                  /**< Model host information */
}
iwc_model_info;


/* MISC FUNCTIONS *************************************************************/

/** Maximum function */
#define max(a, b) ((a) > (b) ? (a) : (b))

#endif  // __IWCONNECT_H
